@@ -56,6 +56,29 @@ class CBInfoResponse:
             'build_status': build_status
         }
 
+    def set_image_info_response(
+        self, image: str, source_ip: str, is_running: bool,
+        arch: str, selection: str, binary_packages: List[str] = [],
+        log_file: str = 'unknown', solver_file: str = 'unknown',
+        utc_modification_time: str = 'unknown',
+        build_status: str = 'unknown'
+    ) -> None:
+        self.info_response_dict = {
+            **self.info_response_dict,
+            'project': image,
+            'source_ip': source_ip,
+            'is_running': is_running,
+            'image': {
+                'arch': arch,
+                'selection': selection
+            },
+            'binary_packages': binary_packages,
+            'log_file': log_file,
+            'solver_file': solver_file,
+            'utc_modification_time': utc_modification_time,
+            'build_status': build_status
+        }
+
     def set_package_info_response_result(
         self, binary_packages: List[str], prepare_log_file: str, log_file: str,
         solver_file: str, utc_modification_time: str,
@@ -69,5 +92,16 @@ class CBInfoResponse:
         self.info_response_dict['utc_modification_time'] = utc_modification_time
         self.info_response_dict['build_status'] = build_status
 
+    def set_image_info_response_result(
+        self, binary_packages: List[str], log_file: str,
+        solver_file: str, utc_modification_time: str,
+        build_status: str
+    ) -> None:
+        self.info_response_dict['binary_packages'] = binary_packages
+        self.info_response_dict['log_file'] = log_file
+        self.info_response_dict['solver_file'] = solver_file
+        self.info_response_dict['utc_modification_time'] = utc_modification_time
+        self.info_response_dict['build_status'] = build_status
+
     def get_data(self) -> Dict:
         return self.info_response_dict
